define(
//begin v1.x content
({
	"descTemplate": "${2} - ${3} / ${1} ${0}",
	"firstTip": "Első oldal",
	"lastTip": "Utolsó oldal",
	"nextTip": "Következő oldal",
	"prevTip": "Előző oldal",
	"itemTitle": "elemek",
	"singularItemTitle": "elem",
	"pageStepLabelTemplate": "${0}. oldal",
	"pageSizeLabelTemplate": "${0} elem oldalanként",
	"allItemsLabelTemplate": "Összes elem",
	"gotoButtonTitle": "Ugrás adott oldalra",
	"dialogTitle": "Ugrás adott oldalra",
	"dialogIndication": "Adja meg az oldalszámot",
	"pageCountIndication": " (${0} oldal)",
	"dialogConfirm": "Mehet",
	"dialogCancel": "Mégse",
	"all": "mind"
})
//end v1.x content
);

